==> zio-aws-macie2_2.12-5.17.217.1-sources.jar: zio/aws/macie2/model/ManagedDataIdentifierSelector.scala <==
package zio.aws.macie2.model
import scala.jdk.CollectionConverters._
sealed trait ManagedDataIdentifierSelector {
  def unwrap: software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector
}
object ManagedDataIdentifierSelector {
  def wrap(
      value: software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector
  ): zio.aws.macie2.model.ManagedDataIdentifierSelector = value match {
    case software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector.ALL =>
      val r = ALL
      r
    case software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector.EXCLUDE =>
      val r = EXCLUDE
      r
    case software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector.INCLUDE =>
      val r = INCLUDE
      r
    case software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector.NONE =>
      val r = NONE
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.macie2.model.ManagedDataIdentifierSelector {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector =
      software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector.UNKNOWN_TO_SDK_VERSION
  }
  case object ALL extends zio.aws.macie2.model.ManagedDataIdentifierSelector {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector =
      software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector.ALL
  }
  case object EXCLUDE
      extends zio.aws.macie2.model.ManagedDataIdentifierSelector {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector =
      software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector.EXCLUDE
  }
  case object INCLUDE
      extends zio.aws.macie2.model.ManagedDataIdentifierSelector {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector =
      software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector.INCLUDE
  }
  case object NONE extends zio.aws.macie2.model.ManagedDataIdentifierSelector {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector =
      software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector.NONE
  }
}

==> zio-aws-macie2_2.12-7.21.15.8-sources.jar: zio/aws/macie2/model/ManagedDataIdentifierSelector.scala <==
package zio.aws.macie2.model
import scala.jdk.CollectionConverters._
sealed trait ManagedDataIdentifierSelector {
  def unwrap: software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector
}
object ManagedDataIdentifierSelector {
  def wrap(
      value: software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector
  ): zio.aws.macie2.model.ManagedDataIdentifierSelector = value match {
    case software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector.ALL =>
      val r = ALL
      r
    case software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector.EXCLUDE =>
      val r = EXCLUDE
      r
    case software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector.INCLUDE =>
      val r = INCLUDE
      r
    case software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector.NONE =>
      val r = NONE
      r
    case software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector.RECOMMENDED =>
      val r = RECOMMENDED
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.macie2.model.ManagedDataIdentifierSelector {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector =
      software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector.UNKNOWN_TO_SDK_VERSION
  }
  case object ALL extends zio.aws.macie2.model.ManagedDataIdentifierSelector {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector =
      software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector.ALL
  }
  case object EXCLUDE
      extends zio.aws.macie2.model.ManagedDataIdentifierSelector {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector =
      software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector.EXCLUDE
  }
  case object INCLUDE
      extends zio.aws.macie2.model.ManagedDataIdentifierSelector {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector =
      software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector.INCLUDE
  }
  case object NONE extends zio.aws.macie2.model.ManagedDataIdentifierSelector {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector =
      software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector.NONE
  }
  case object RECOMMENDED
      extends zio.aws.macie2.model.ManagedDataIdentifierSelector {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector =
      software.amazon.awssdk.services.macie2.model.ManagedDataIdentifierSelector.RECOMMENDED
  }
}
